==> eudplib-0.71.6-cp310-cp310-win_amd64.whl: eudplib/core/rawtrigger/strdict/__init__.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2022 Armoha

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
"""

from .flingy import DefFlingyDict
from .icon import DefIconDict
from .image import DefImageDict
from .iscript import DefIscriptDict
from .portrait import DefPortraitDict
from .sprite import DefSpriteDict
from .stattxt import DefTBLDict
from .tech import DefTechDict
from .trg import DefAIScriptDict, DefLocationDict, DefSwitchDict, DefUnitDict
from .unitorder import DefUnitOrderDict
from .upgrade import DefUpgradeDict
from .weapon import DefWeaponDict

==> eudplib-0.73.19-cp310-cp310-win_amd64.whl: eudplib/core/rawtrigger/strdict/__init__.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2022 Armoha

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
"""

from .flingy import DefFlingyDict
from .icon import DefIconDict
from .image import DefImageDict
from .iscript import DefIscriptDict
from .portrait import DefPortraitDict
from .sprite import DefSpriteDict
from .stattxt import DefStatTextDict
from .tech import DefTechDict
from .trg import DefAIScriptDict, DefLocationDict, DefSwitchDict, DefUnitDict
from .unitorder import DefUnitOrderDict
from .upgrade import DefUpgradeDict
from .weapon import DefWeaponDict
